import Vapor

enum TILError {
    case acronymNotFound
    case userNotFound
    case categoryNotFound
    case invalidUserID
    case duplicateAcronym(String)
}

extension TILError: AbortError {
    var status: HTTPStatus {
        switch self {
        case .acronymNotFound, .userNotFound, .categoryNotFound:
            return .notFound
        case .invalidUserID:
            return .badRequest
        case .duplicateAcronym:
            return .conflict
        }
    }

    var reason: String {
        switch self {
        case .acronymNotFound:
            return "Acronym not found"
        case .userNotFound:
            return "User not found"
        case .categoryNotFound:
            return "Category not found"
        case .invalidUserID:
            return "Invalid user ID provided"
        case .duplicateAcronym(let short):
            return "Acronym '\(short)' already exists"
        }
    }
}
