import Vapor

struct CustomErrorMiddleware: AsyncMiddleware {
    func respond(to request: Request, chainingTo next: AsyncResponder) async throws -> Response {
        do {
            return try await next.respond(to: request)
        } catch {
            // 记录错误
            request.logger.error("\(error)")

            // 构建错误响应
            let status: HTTPStatus
            let reason: String

            if let abortError = error as? AbortError {
                status = abortError.status
                reason = abortError.reason
            } else {
                status = .internalServerError
                #if DEBUG
                    reason = "\(error)"
                #else
                    reason = "Something went wrong."
                #endif
            }

            // 创建JSON响应
            let response = Response(status: status)
            try response.content.encode(CustomErrorResponse(error: true, reason: reason))

            return response
        }
    }
}

struct CustomErrorResponse: Content {
    let error: Bool
    let reason: String
}