import Fluent
import FluentPostgresDriver
import NIOSSL
import Vapor

// configures your application
public func configure(_ app: Application) async throws {
    // uncomment to serve files from /Public folder
    // app.middleware.use(FileMiddleware(publicDirectory: app.directory.publicDirectory))

    // 移除默认的错误中间件
    app.middleware = .init()
    // 添加自定义错误中间件
    app.middleware.use(CustomErrorMiddleware())


    let databaseName: String
    let databasePort: Int

    if app.environment == .testing {
        // 要与测试数据库端口一致
        databasePort = 5434
        databaseName = "vapor-test"
    } else {
        databasePort = Environment.get("DATABASE_PORT").flatMap(Int.init(_:)) ?? SQLPostgresConfiguration.ianaPortNumber
        databaseName = Environment.get("DATABASE_NAME") ?? "vapor_database"
    }

    app.databases.use(
        DatabaseConfigurationFactory.postgres(
            configuration: .init(
                hostname: Environment.get("DATABASE_HOST") ?? "localhost",
                port: databasePort,
                username: Environment.get("DATABASE_USERNAME") ?? "vapor_username",
                password: Environment.get("DATABASE_PASSWORD") ?? "vapor_password",
                database: databaseName,
                tls: .prefer(try .init(configuration: .clientDefault)))
        ), as: .psql)

    app.migrations.add(CreateUser())
    app.migrations.add(CreateAcronym())
    app.migrations.add(CreateCategory())
    app.migrations.add(CreateAcronymCategoryPivot())

    // 开发环境使用 debug 级别
    if app.environment == .development {
        app.logger.logLevel = .debug
    } else {
        // 生产环境使用 notice 级别
        app.logger.logLevel = .notice
    }
    
    // register routes
    try routes(app)
}
